Django gcm android ios's documentation!
=======================================

django-gcm-android-ios is a simple Django app to send a message using Google Cloud Messaging HTTP connection server protocol.


.. image:: https://travis-ci.org/hugobrilhante/django-gcm-android-ios.svg
   :target: https://travis-ci.org/hugobrilhante/django-gcm-android-ios


.. image:: https://coveralls.io/repos/hugobrilhante/django-gcm-android-ios/badge.svg?branch=master&service=github
   :target: https://coveralls.io/github/hugobrilhante/django-gcm-android-ios?branch=master

.. image:: https://readthedocs.org/projects/django-gcm-android-ios/badge/?version=latest
   :target: http://django-gcm-android-ios.readthedocs.org/en/latest/
   :alt: Documentation Status

Contents:

.. toctree::
   :maxdepth: 2

   tutorial



======
Author
======

- `Hugo Brilhante <https://github.com/hugobrilhante>`_

=============
Main features
=============
- Python:  2,7, 3.4.
- Django:  1.7, 1.8.
- API using Django Rest Framework `django-rest-framework <http://django-rest-framework.org>`_
- Requests processing http/https using the library `requests <http://github.com/kennethreitz/requests/>`_.
- Excellent coverage tests (> 80%).

=====
Links
=====

- `Github <https://github.com/hugobrilhante/django-gcm-android-ios/>`_
- `Travis CI <https://travis-ci.org/hugobrilhante/django-gcm-android-ios/>`_
- `Coveralls <https://coveralls.io/github/hugobrilhante/django-gcm-android-ios/>`_


==========
References
==========

- `Google Cloud Messaging <https://developers.google.com/cloud-messaging/>`_

=======
License
=======

.. include:: ../LICENSE